@@ -524,9 +524,19 @@ class LaharFlowData(object):
         self.txt_files = [f for f in self.files if f.endswith('.txt')]
         self.txt_files.sort()
     
-    def get_snapshot_files(self):
+    def _snapshot_txt_files(self):
         txt_files = [f.strip('.txt') for f in self.txt_files if f.strip('.txt').isnumeric()]
+        txt_files.sort()
+        return txt_files
+    
+    def _snapshot_nc_files(self):
         nc_files = [f.strip('.nc') for f in self.nc_files if f.strip('.nc').isnumeric()]
+        nc_files.sort()
+        return nc_files
+
+    def get_snapshot_files(self):
+        txt_files = self._snapshot_txt_files()
+        nc_files = self._snapshot_nc_files()
         sfiles = list(set(txt_files + nc_files))
         sfiles.sort()
         return sfiles
@@ -1008,7 +1018,7 @@ class LaharFlowData(object):
             self.MaxSpeed = None
             self.MaxConc = None
         
-        last_outfile = self.get_snapshot_files()[-1]
+        last_outfile = self._snapshot_nc_files()[-1]
         try:
             maxE, maxD = nc_min_max(last_outfile, var='elevation_change')
             self.MaxDeposit = maxD['elevation_change']
